@@ -1,5 +1,6 @@
 import pytest
 import pkg_resources
+from setuptools_scm import dump_version, get_version, PRETEND_KEY
 from setuptools_scm.version import guess_next_version, meta, format_version
 
 
@@ -29,15 +30,15 @@ VERSIONS = {
 
 @pytest.mark.parametrize('version,scheme,expected', [
     ('exact', 'guess-next-dev node-and-date', '1.1'),
-    ('zerodistance', 'guess-next-dev node-and-date', '1.2.dev0+nNone'),
-    ('dirty', 'guess-next-dev node-and-date', '1.2.dev0+nNone.dtime'),
-    ('distance', 'guess-next-dev node-and-date', '1.2.dev3+nNone'),
-    ('distancedirty', 'guess-next-dev node-and-date', '1.2.dev3+nNone.dtime'),
+    ('zerodistance', 'guess-next-dev node-and-date', '1.2.dev0'),
+    ('dirty', 'guess-next-dev node-and-date', '1.2.dev0+dtime'),
+    ('distance', 'guess-next-dev node-and-date', '1.2.dev3'),
+    ('distancedirty', 'guess-next-dev node-and-date', '1.2.dev3+dtime'),
     ('exact', 'post-release node-and-date', '1.1'),
-    ('zerodistance', 'post-release node-and-date', '1.1.post0+nNone'),
-    ('dirty', 'post-release node-and-date', '1.1.post0+nNone.dtime'),
-    ('distance', 'post-release node-and-date', '1.1.post3+nNone'),
-    ('distancedirty', 'post-release node-and-date', '1.1.post3+nNone.dtime'),
+    ('zerodistance', 'post-release node-and-date', '1.1.post0'),
+    ('dirty', 'post-release node-and-date', '1.1.post0+dtime'),
+    ('distance', 'post-release node-and-date', '1.1.post3'),
+    ('distancedirty', 'post-release node-and-date', '1.1.post3+dtime'),
 ])
 def test_format_version(version, monkeypatch, scheme, expected):
     version = VERSIONS[version]
@@ -47,3 +48,17 @@ def test_format_version(version, monkeypatch, scheme, expected):
         version,
         version_scheme=vs,
         local_scheme=ls) == expected
+
+
+def test_dump_version_doesnt_bail_on_value_error(tmpdir):
+    write_to = "VERSION"
+    version = str(VERSIONS['exact'].tag)
+    with pytest.raises(ValueError) as exc_info:
+        dump_version(tmpdir.strpath, version, write_to)
+    assert str(exc_info.value).startswith("bad file format:")
+
+
+def test_dump_version_works_with_pretend(tmpdir, monkeypatch):
+    monkeypatch.setenv(PRETEND_KEY, '1.0')
+    get_version(write_to=str(tmpdir.join('VERSION.txt')))
+    assert tmpdir.join('VERSION.txt').read() == '1.0'
